# Contributing to *neurosynchro*

Contributions are welcome!

The best way to get involved is to
[file an issue on GitHub](https://github.com/pkgw/neurosynchro/issues/new) or
[submit a pull request](https://github.com/pkgw/neurosynchro/pulls) if you
already have changes to submit. The project has been spearheaded by
[Peter K. G. Williams](https://newton.cx/~peter/) thus far but it is intended
to be a community resource, developed in standard open-source style.

We only ask that you abide by the [code of conduct](./CODE_OF_CONDUCT.md).
Basically, don’t be a jerk. Also, code contributions will be assumed to be
licensed under the MIT License, and documentation contributions will be
assumed to be licensed under the Creative Commons Attribution-ShareAlike 4.0
International License.
